// Sensor time logger robot
class STLR extends SkidSteeredRobot config(USARBot);

var config float samplingTime;
var float nextSamplingTime;
var bool bLogFileOpen;

var FileLog senLog;

simulated function Tick(float Delta)
{
    local int i;
    local float time, getDataTime;
    local string outstring, senStr;
    local bool goodClock;

    // Process robot actions
    super.Tick(Delta);

    time = Level.TimeSeconds;

    if(time >= nextSamplingTime) {
        if(!bLogFileOpen) {
            PrepareLog();
            bLogFileOpen = true;
        }
        nextSamplingTime += samplingTime;
        senStr = string(time);
        goodClock = true;

        for(i=0; i < SensorList.Length; i++) {
            Clock(getDataTime);
            if(SensorList[i].ItemType == "RangeScanner")
                SensorList[i].Set("SCAN","");
            outstring = SensorList[i].GetData();
            UnClock(getDataTime);
            if(getDataTime <0) {
                goodClock = false;
                break;
            }
            senStr = senStr$","$getDataTime;
        }
        if(goodClock)
            senLog.Logf(senStr);
    }
}

function PrepareLog()
{
    local int i;
    local string senCaption;

    senLog = Spawn(class'FileLog');
    senLog.OpenLog("STLR SENLog-"$USARRemoteBot(Controller).RobotName,"txt");

    senCaption = "Time";
    for(i=0; i < SensorList.Length; i++) {
        senCaption = senCaption$","$SensorList[i].ItemName$"("$SensorList[i].ItemType$")";
    }

    senLog.Logf(senCaption);
}

simulated event Destroyed()
{
    senLog.CloseLog();
    super.Destroyed();
}

function Timer()
{
    //Do not call sensors
}


defaultproperties
{
    samplingTime=2

  //---Wheel information.  Since the P2AT has four wheels, we have four of these definitions
  // The next four definitions will create a 4-wheel skid steer P2AT where all the wheels are locked (cannot be steered)

    // Number=0 indicates that this wheel is the first JointPart defined in USARBot.ini (ORDER MATTERS!)
    // Power=Right_Powered tells USARSim to spin this wheel using the right throttle
    // Note that since the variables SteerType and MaxSteerAngle are not defined, this wheel is not steered (steering is locked)
    Wheels(0)=(Number=0,PowerType=Left_Powered);

    // Number=1 indicates that this wheel is the second JointPart defined in USARBot.ini (ORDER MATTERS!)
    // Power=Left_Powered tells USARSim to spin this wheel using the left throttle
    // Note that since the variables SteerType and MaxSteerAngle are not defined, this wheel is not steered (steering is locked)
    Wheels(1)=(Number=1,PowerType=Right_Powered);

    // Number=2 indicates that this wheel is the third JointPart defined in USARBot.ini (ORDER MATTERS!)
    // Power=Left_Powered tells USARSim to spin this wheel using the right throttle
    // Note that since the variables SteerType and MaxSteerAngle are not defined, this wheel is not steered (steering is locked)
    Wheels(2)=(Number=2,PowerType=Left_Powered);

    // Number=3 indicates that this wheel is the fourth JointPart defined in USARBot.ini (ORDER MATTERS!)
    // Power=Left_Powered tells USARSim to spin this wheel using the left throttle
    // Note that since the variables SteerType and MaxSteerAngle are not defined, this wheel is not steered (steering is locked)
    Wheels(3)=(Number=3,PowerType=Right_Powered);
  //---

  //--Other Robot's Properties
    bDebug=false
    StaticMesh=StaticMesh'USARSim_Vehicles_Meshes.Zerg.ZergBody'
    DrawScale=4.762
    DrawScale3D=(X=1.0,Y=1.0,Z=1.0)

    ChassisMass=1.000000

    // Configuration Parameters. Note: these variables need to be correspond to your robot's model.
    WheelRadius=0.13                        // Wheel Radius, in unreal units. Note: Value is in meters
    Dimensions=(X=0.5239,Y=0.4968,Z=0.2914) // X=Length=0.5239m, Y=Width=0.4968m, Z=Height=0.2914m
    maxSpinSpeed=6.2832                     // Maximum wheel's spin speed is max_tran_speed/wheel_radius=0.7/0.13=5.385

    Begin Object Class=KarmaParamsRBFull Name=KParams0
        bKNonSphericalInertia=True
        KInertiaTensor(0)=0.0156
        KInertiaTensor(3)=0.0093
        KInertiaTensor(5)=0.0225
        KCOMOffset=(X=0.000000,Z=0.000000)
        KActorGravScale=2.58
        KLinearDamping=0
        KAngularDamping=0
        KMaxAngularSpeed=100
        KMaxSpeed=25000
        KStartEnabled=True
        bHighDetailOnly=False
        bClientOnly=False
        bKDoubleTickRate=True
        KFriction=0.9
        Name="KParams0"
    End Object
    KParams=KarmaParamsRBFull'USARBot.STLR.KParams0'
  //--
}
